@@ -212,14 +212,14 @@ class RaiderAdmin(object):
 
     def get_open_payouts(self, limit: int = 100, offset: int = 0) -> typing.List[Payout]:
         with self.cursor() as cur:
-            query = "SELECT * FROM `payout` WHERE `payout`.`status`=\"pending\" ORDER BY `payout`.`updated_at` LIMIT %s OFFSET %s;"
+            query = "SELECT * FROM `payout` WHERE `payout`.`status`=\"pending\" ORDER BY `payout`.`updated_at` DESC LIMIT %s OFFSET %s;"
             cur.execute(query, (limit, offset))
             records = cur.fetchall()
             return [Payout.from_tuple(payout) for payout in records]
 
     def get_all_payouts(self, limit: int = 100, offset: int = 0) -> typing.List[Payout]:
         with self.cursor() as cur:
-            query = "SELECT * FROM `payout` ORDER BY `payout`.`updated_at` LIMIT %s OFFSET %s;"
+            query = "SELECT * FROM `payout` ORDER BY `payout`.`updated_at` DESC LIMIT %s OFFSET %s;"
             cur.execute(query, (limit, offset))
             records = cur.fetchall()
             return [Payout.from_tuple(payout) for payout in records]
